#' An \code{htmlwidget} interface to the
#' ApexCharts javascript chart library
#' 
#' This package allow you to use ApexCharts.js (\url{https://apexcharts.com/}),
#' to create interactive and modern SVG charts.
#' 
#' @name apexcharter-package
#' @docType package
#' @author Victor Perrier (@@dreamRs_fr)
NULL

#' apexcharter exported operators and S3 methods
#' 
#' The following functions are imported and then re-exported
#' from the apexcharter package to avoid listing the magrittr
#' as Depends of apexcharter
#' 
#' @name apexcharter-exports
NULL

#' @importFrom magrittr %>%
#' @name %>%
#' @export
#' @rdname apexcharter-exports
NULL

#' @importFrom ggplot2 aes
#' @name aes
#' @export
#' @rdname apexcharter-exports
NULL

#' @importFrom ggplot2 vars
#' @name vars
#' @export
#' @rdname apexcharter-exports
NULL

#' @importFrom ggplot2 label_value
#' @name label_value
#' @export
#' @rdname apexcharter-exports
NULL

#' @importFrom htmlwidgets JS
#' @name JS
#' @export
#' @rdname apexcharter-exports
NULL
